@@ -4,6 +4,7 @@ import pandas as pd
 
 from pymbse.optim.design_variable.DesignVariable import DesignVariable
 from pymbse.optim.design_variable.GeneticDesignVariable import GeneticDesignVariable
+from pymbse.commons import json_file
 
 
 def init_design_variables_with_csv(csv_path: str) -> List[GeneticDesignVariable]:
@@ -17,13 +18,17 @@ def init_design_variables_with_csv(csv_path: str) -> List[GeneticDesignVariable]
     return init_design_variables_with_df(design_variables_df)
 
 
-def init_design_variables_with_df(design_variables_df: pd.DataFrame) -> list:
-    design_variables = []
-    for _, row in design_variables_df.iterrows():
-        if 'bits' in row:
-            dv = GeneticDesignVariable(**row)
-        else:
-            dv = DesignVariable(**row)
-        design_variables.append(dv)
+def init_design_variables_with_json(json_path: str) -> list:
+    design_variables = json_file.read(json_path)
+    return [initialize_design_variable(design_variable) for design_variable in design_variables]
 
-    return design_variables
+
+def init_design_variables_with_df(design_variables_df: pd.DataFrame) -> list:
+    return [initialize_design_variable(row) for (_, row) in design_variables_df.iterrows()]
+
+
+def initialize_design_variable(row):
+    if 'bits' in row:
+        return GeneticDesignVariable(**row)
+    else:
+        return DesignVariable(**row)
